@@ -43,15 +43,10 @@ TEMPLATE_LOADERS = (
 )
 
 
-# Optional separate database settings
+# Local database settings. These should work well with http://postgresapp.com/.
 
-#DATABASES["default"]["NAME"] = ""
+DATABASES["default"]["NAME"] = "{{ project_name }}"
 
-#DATABASES["default"]["USER"] = ""
+DATABASES["default"]["USER"] = "{{ user }}"
 
-#DATABASES["default"]["PASSWORD"] = ""
-
-
-# Optional console-based email backend.
-
-#EMAIL_BACKEND = "django.core.mail.backends.console.EmailBackend"
\ No newline at end of file
+DATABASES["default"]["PASSWORD"] = ""
\ No newline at end of file
